Welcome to ytree.
=================

ytree is a tool for working with merger-tree data from multiple sources.
ytree is an extension of the `yt <http://yt-project.org/>`_ analysis toolkit
and provides a similar interface for merger-tree data that includes universal
field names, derived fields, and symbolic units.  ytree can create
merger-trees from Gadget FoF/Subfind catalogs, either for all halos or for a
specific set of halos.  ytree is able to load in merger-tree from the following
formats:

- `Amiga Halo Finder <http://popia.ft.uam.es/AHF/Download.html>`_
- `Consistent-Trees <https://bitbucket.org/pbehroozi/consistent-trees>`_
- `LHaloTree <http://adsabs.harvard.edu/abs/2005MNRAS.364.1105S>`_
- `Rockstar <https://bitbucket.org/gfcstanford/rockstar>`_ halo catalogs
  without consistent-trees
- :ref:`merger-trees made with ytree <treefarm>`

All formats can be saved with a universal format that can be reloaded
with ytree.  Individual trees for single halos can also be saved.

Table of Contents
=================

.. toctree::
   :maxdepth: 2

   Installation.rst
   Data.rst
   Arbor.rst
   Fields.rst
   TreeFarm.rst
   Conduct.rst
   Contributing.rst
   Developing.rst
   Help.rst
   Citing.rst
   reference.rst

.. include:: ../../CITATION.rst

Search
======

* :ref:`search`

